summaryrefslogtreecommitdiff
path: root/libpod
diff options
context:
space:
mode:
Diffstat (limited to 'libpod')
-rw-r--r--libpod/pod.go10
1 files changed, 6 insertions, 4 deletions
diff --git a/libpod/pod.go b/libpod/pod.go
index 9f7ad5876..f7059800a 100644
--- a/libpod/pod.go
+++ b/libpod/pod.go
@@ -165,11 +165,13 @@ func startNode(node *containerNode, setError bool, ctrErrors map[string]error, c
// Going to start the container, mark us as visited
ctrsVisited[node.id] = true
// Start the container
ctrErrored := false
- if err := node.container.initAndStart(); err != nil {
- ctrErrored = true
- ctrErrors[node.id] = err
+ if node.container.state.State != ContainerStateRunning {
+ if err := node.container.initAndStart(); err != nil {
+ ctrErrored = true
+ ctrErrors[node.id] = err
+ }
}
// Recurse to anyone who depends on us and start them
@@ -165,11 +165,13 @@ func startNode(node *containerNode, setError bool, ctrErrors map[string]error, c
// Going to start the container, mark us as visited
ctrsVisited[node.id] = true
- // Start the container
+ // Start the container (only if it is not running)
ctrErrored := false